==> VF-41_AJ105_1989_by_Reflected.zip: description.lua <==
livery = {


--Diffuse  -----------------------------------

{"HB_F14_EXT_01", 0 ,"HB_F14_EXT_01",false};
{"HB_F14_EXT_02", 0 ,"HB_F14_EXT_02",false};
{"HB_F14_EXT_02", ROUGHNESS_METALLIC ,"HB_F14_EXT_02_RoughMet",false};
{"HB_F14_EXT_02", 1, "HB_F14_EXT_02_Nrm", false};
{"HB_F14_EXT_03", 0 ,"HB_F14_EXT_03",false};
{"HB_F14_EXT_03", ROUGHNESS_METALLIC ,"HB_F14_EXT_03_RoughMet",false};
{"HB_F14_EXT_03", 1 ,"HB_F14_EXT_03_Nrm",false};
{"HB_F14_EXT_04", 0 ,"HB_F14_EXT_04",false};
{"HB_F14_EXT_04", ROUGHNESS_METALLIC ,"HB_F14_EXT_04_RoughMet",false};
{"HB_F14_EXT_04", 1 ,"HB_F14_EXT_04_Nrm",false};
{"HB_F14_EXT_TAIL", 0 ,"HB_F14_EXT_TAIL",false};
{"HB_F14_EXT_TAIL", ROUGHNESS_METALLIC ,"HB_F14_EXT_TAIL_RoughMet",false};
{"HB_F14_EXT_TAIL", 1, "HB_F14_EXT_TAIL_Nrm", false};
{"HB_F14_WING_LEFT_01", 0 ,"HB_F14_WING_LEFT",false};
{"HB_F14_WING_RIGHT", 0 ,"HB_F14_WING_RIGHT",false};
{"HB_F14_LOD1_3in1", 0 ,"HB_F14_LOD1_3in1",false};
{"HB_F14_EXT_DROPTANKS", 0 ,"HB_F14_EXT_DROPTANK",false};
{"HB_F14_EXT_PHOENIXRAILS", 0 ,"HB_F14_EXT_PHOENIXPYLONS",false};
{"HB_F14_EXT_PYLONS", 0 ,"HB_F14_EXT_PYLONS_01",false};
{"HB_F14_TCS", 0 ,"HB_F14_EXT_TCS",false};
{"HB_F14_EXT_PILOT", 0 ,"HB_F14_EXT_PILOT",false};
{"HB_F14_WING_LEFT_01", ROUGHNESS_METALLIC ,"HB_F14_WING_LEFT_RoughMet",false};
{"HB_F14_WING_RIGHT", ROUGHNESS_METALLIC ,"HB_F14_WING_RIGHT_RoughMet",false};



{"HB_F14_EXT_PILOT_HELMET", 0 ,"HB_F14_EXT_PILOT_HELMET",false};
{"HB_F14_EXT_RIO_HELMET", 0 ,"HB_F14_EXT_PILOT_HELMET",false};

{"HB_F14_EXT_PILOT_SUIT", 0 ,"HB_F14_EXT_PILOT_SUIT",false};

}
name = "VF-41 AJ105 1989 by Reflected"

--countries = {"USA", "RUS", "FRA", "UKR", "SPN", "NETH", "TUR", "BEL", "GER", "NOR", "CAN", "DEN", "UK", "GRG", "ISR", "ABH", "RSO"}

==> VF-41_AJ107_1979_by_Reflected.zip: description.lua <==
livery = {


--Diffuse  -----------------------------------

{"HB_F14_EXT_01", 0 ,"HB_F14_EXT_01",false};
{"HB_F14_EXT_01", ROUGHNESS_METALLIC ,"HB_F14_EXT_01_RoughMet",false};
{"HB_F14_EXT_02", 0 ,"HB_F14_EXT_02",false};
{"HB_F14_EXT_02", ROUGHNESS_METALLIC ,"HB_F14_EXT_02_RoughMet",false};
{"HB_F14_EXT_02", 1, "HB_F14_EXT_02_Nrm", false};
{"HB_F14_EXT_03", 0 ,"HB_F14_EXT_03",false};
{"HB_F14_EXT_03", ROUGHNESS_METALLIC ,"HB_F14_EXT_03_RoughMet",false};
{"HB_F14_EXT_03", 1 ,"HB_F14_EXT_03_Nrm",false};
{"HB_F14_EXT_04", 0 ,"HB_F14_EXT_04",false};
{"HB_F14_EXT_04", ROUGHNESS_METALLIC ,"HB_F14_EXT_04_RoughMet",false};
{"HB_F14_EXT_04", 1 ,"HB_F14_EXT_04_Nrm",false};
{"HB_F14_EXT_TAIL", 0 ,"HB_F14_EXT_TAIL",false};
{"HB_F14_EXT_TAIL", ROUGHNESS_METALLIC ,"HB_F14_EXT_TAIL_RoughMet",false};
{"HB_F14_EXT_TAIL", 1, "HB_F14_EXT_TAIL_Nrm", false};
{"HB_F14_WING_LEFT_01", 0 ,"HB_F14_WING_LEFT",false};
{"HB_F14_WING_LEFT_01", ROUGHNESS_METALLIC ,"HB_F14_WING_LEFT_RoughMet",false};
{"HB_F14_WING_RIGHT", 0 ,"HB_F14_WING_RIGHT",false};
{"HB_F14_WING_RIGHT", ROUGHNESS_METALLIC ,"HB_F14_WING_RIGHT_RoughMet",false};
{"HB_F14_LOD1_3in1", 0 ,"HB_F14_LOD1_3in1",false};
{"HB_F14_EXT_DROPTANKS", 0 ,"HB_F14_EXT_DROPTANK",false};
{"HB_F14_EXT_PHOENIXRAILS", 0 ,"HB_F14_EXT_PHOENIXPYLONS",false};
{"HB_F14_EXT_PHOENIXRAILS", ROUGHNESS_METALLIC ,"HB_F14_EXT_PHOENIXPYLONS_RoughMet",false};
{"HB_F14_EXT_PYLONS", 0 ,"HB_F14_EXT_PYLONS_01",false};
{"HB_F14_TCS", 0 ,"HB_F14_EXT_TCS",false};
{"HB_F14_TCS", ROUGHNESS_METALLIC, "HB_F14_EXT_TCS_RoughMet", false};
{"HB_F14_EXT_PILOT", 0 ,"HB_F14_EXT_PILOT",false};
{"HB_F14_AIM-54", 0 ,"HB_F14_AIM-54",false};
{"HB_F14_EXT_INTAKERAMPS", 0 ,"HB_F14_EXT_INTAKERAMPS",false};


{"HB_F14_EXT_PILOT_HELMET", 0 ,"HB_F14_EXT_PILOT_HELMET",false};
{"HB_F14_EXT_RIO_HELMET", 0 ,"HB_F14_EXT_PILOT_HELMET",false};

{"HB_F14_EXT_PILOT_SUIT", 0 ,"HB_F14_EXT_PILOT_SUIT",false};

}
name = "VF-41 AJ107 1979 by Reflected"

--countries = {"USA", "RUS", "FRA", "UKR", "SPN", "NETH", "TUR", "BEL", "GER", "NOR", "CAN", "DEN", "UK", "GRG", "ISR", "ABH", "RSO"}
